# Preparation

## Install

```bash
pip install prompttrail
```

or install the latest version from the repository:

```bash
pip install git+https://github.com/combinatrix-ai/PromptTrail.git
```

```{Warning}
Currently, Python 3.11 or later is required.
```
